# Plotting utilities

All of the core plotting functions live in the small `pl` submodule:


```{eval-rst}
.. currentmodule:: cytonormpy.pl

.. autosummary::
    :toctree: ../generated/
    :nosignatures:

    cytonormpy.pl.scatter
    cytonormpy.pl.histogram
    cytonormpy.pl.cv_heatmap
    cytonormpy.pl.emd
    cytonormpy.pl.mad
    cytonormpy.pl.splineplot

```
